@@ -13,6 +13,7 @@ from rich.text import Text
 from rich.console import Group
 from simpleconf import Config
 from slugify import slugify  # type: ignore
+from varname import varname, VarnameException
 
 from .defaults import CONFIG, CONFIG_FILES, CONSOLE_WIDTH
 from .exceptions import ProcDependencyError, PipenSetDataError
@@ -67,7 +68,14 @@ class Pipen:
         """Constructor"""
         self.procs: List[Proc] = None
         self.pbar: PipelinePBar = None
-        self.name = name or f"pipen-{self.__class__.PIPELINE_COUNT}"
+        if name is not None:
+            self.name = name
+        else:
+            try:
+                self.name = varname()
+            except VarnameException:
+                self.name = f"pipen-{self.__class__.PIPELINE_COUNT}"
+
         self.desc = desc
         self.outdir = Path(
             outdir or f"./{slugify(self.name)}_results"
@@ -117,7 +125,7 @@ class Pipen:
         logger.setLevel(self.config.loglevel.upper())
         log_rich_renderable(pipen_banner(), "magenta", logger.info)
         try:
-            self._build_proc_relationships()
+            self.build_proc_relationships()
             self._log_pipeline_info()
             await plugin.hooks.on_start(self)
 
@@ -217,6 +225,7 @@ class Pipen:
         """
         if clear:
             self.starts = []
+            self.procs = None
 
         for proc in procs:
             if isinstance(proc, (list, tuple)):
@@ -327,8 +336,11 @@ class Pipen:
         self.config.plugin_opts.update(self._kwargs.pop("plugin_opts", {}))
         self.config.update(self._kwargs)
 
-    def _build_proc_relationships(self) -> None:
+    def build_proc_relationships(self) -> None:
         """Build the proc relationships for the pipeline"""
+        if self.procs:
+            return
+
         if not self.starts:
             raise ProcDependencyError(
                 "No start processes specified. "
@@ -344,7 +356,10 @@ class Pipen:
         while nexts:
             logger.debug("- Next processes: %s", nexts)
             # pick up one that can be added to procs
-            for proc in sorted(nexts, key=lambda prc: prc.name):
+            for proc in sorted(
+                nexts,
+                key=lambda prc: (prc.order or 0, prc.name)
+            ):
                 if proc in self.procs:
                     raise ProcDependencyError(
                         f"Cyclic dependency: {proc.name}"
