@@ -16,7 +16,8 @@ from typing import (
     TYPE_CHECKING,
 )
 
-import pandas
+# Slow down the import, try do it at runtime
+# import pandas
 from diot import Diot
 from rich import box
 from rich.panel import Panel
@@ -24,7 +25,6 @@ from slugify import slugify  # type: ignore
 from varname import VarnameException, varname
 from xqute import JobStatus, Xqute
 
-from .channel import Channel
 from .defaults import CONSOLE_WIDTH, ProcInputType
 from .exceptions import (
     ProcInputKeyError,
@@ -49,6 +49,7 @@ from .utils import (
     strsplit,
     update_dict,
     get_shebang,
+    get_base,
 )
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -127,6 +128,11 @@ class Proc(ABC, metaclass=ProcMeta):
         input_data: The input data (will be computed for dependent processes)
         lang: The language for the script to run. Should be the path to the
             interpreter if `lang` is not in `$PATH`.
+        order: The execution order for this process. The bigger the number
+            is, the later the process will be executed. Default: 0.
+            Note that the dependent processes will always be executed first.
+            This doesn't work for start processes either, whose orders are
+            determined by `Pipen.set_starts()`
         output: The output keys for the output channel
             (the data will be computed)
         plugin_opts: Options for process-level plugins
@@ -154,6 +160,7 @@ class Proc(ABC, metaclass=ProcMeta):
     input: Union[str, Sequence[str]] = None
     input_data: Any = None
     lang: str = None
+    order: int = None
     output: Union[str, Sequence[str]] = None
     plugin_opts: Mapping[str, Any] = None
     requires: Union[Type["Proc"], Sequence[Type["Proc"]]] = None
@@ -179,6 +186,7 @@ class Proc(ABC, metaclass=ProcMeta):
         num_retries: int = None,
         forks: int = None,
         input_data: Any = None,
+        order: int = None,
         plugin_opts: Mapping[str, Any] = None,
         requires: Sequence[Type["Proc"]] = None,
         scheduler: str = None,
@@ -207,6 +215,7 @@ class Proc(ABC, metaclass=ProcMeta):
             forks: New forks for the new process
             input_data: The input data for the process. Only when this process
                 is a start process
+            order: The order to execute the new process
             plugin_opts: The new plugin options, unspecified items will be
                 inherited.
             requires: The required processes for the new process
@@ -236,6 +245,8 @@ class Proc(ABC, metaclass=ProcMeta):
             kwargs["cache"] = cache
         if forks is not None:
             kwargs["forks"] = forks
+        if order is not None:
+            kwargs["order"] = order
         if plugin_opts is not None:
             kwargs["plugin_opts"] = update_dict(proc.plugin_opts, plugin_opts)
         if scheduler is not None:
@@ -266,6 +277,8 @@ class Proc(ABC, metaclass=ProcMeta):
         cls.requires = cls._compute_requires()
         if cls.name is None or cls.name == cls.__bases__[0].name:
             cls.name = cls.__name__
+        if cls.__doc__ is None:
+            cls.__doc__ = cls.__bases__[0].__doc__
 
     def __init__(self, pipeline: "Pipen" = None) -> None:
         """Constructor
@@ -307,6 +320,10 @@ class Proc(ABC, metaclass=ProcMeta):
         template_opts.update(self.template_opts or {})
         self.template_opts = template_opts
 
+        plugin_opts = copy_dict(self.pipeline.config.plugin_opts)
+        plugin_opts.update(self.plugin_opts or {})
+        self.plugin_opts = plugin_opts
+
         # input
         self.input = self._compute_input()  # type: ignore
         # output
@@ -338,6 +355,8 @@ class Proc(ABC, metaclass=ProcMeta):
 
     async def _init(self) -> None:
         """Init all other properties and jobs"""
+        import pandas
+
         scheduler_opts = (
             copy_dict(self.pipeline.config.scheduler_opts, 2) or {}
         )
@@ -506,6 +525,9 @@ class Proc(ABC, metaclass=ProcMeta):
         Returns:
             A dict with type and data
         """
+        import pandas
+        from .channel import Channel
+
         # split input keys into keys and types
         input_keys = self.input
         if input_keys and isinstance(input_keys, str):
@@ -554,7 +576,7 @@ class Proc(ABC, metaclass=ProcMeta):
 
         # try match the column names
         # if none matched, use the first columns
-        rest_cols = out.data.columns.difference(out.type)
+        rest_cols = out.data.columns.difference(out.type, False)
         len_rest_cols = len(rest_cols)
         matched_cols = out.data.columns.intersection(out.type)
         needed_cols = [col for col in out.type if col not in matched_cols]
@@ -606,9 +628,13 @@ class Proc(ABC, metaclass=ProcMeta):
         if script.startswith("file://"):
             script_file = Path(script[7:])
             if not script_file.is_absolute():
-                script_file = (
-                    Path(inspect.getfile(self.__class__)).parent / script_file
+                base = get_base(
+                    self.__class__,
+                    Proc,
+                    script,
+                    lambda klass: getattr(klass, "script", None),
                 )
+                script_file = Path(inspect.getfile(base)).parent / script_file
             if not script_file.is_file():
                 raise ProcScriptFileNotFound(
                     f"No such script file: {script_file}"
